@@ -34,7 +34,14 @@ class CliArguments:
 
 class RelyComplyCLI:
     def __init__(self, **credentials):
-        self.gql = RelyComplyGQLClient(**credentials)
+        self._gql = None
+        self.credentials = credentials
+
+    @property
+    def gql(self):
+        if not self._gql:
+            self._gql = RelyComplyGQLClient(**self.credentials)
+        return self._gql
 
     def run_command(self, args):
         try:
@@ -271,4 +278,4 @@ class RelyComplyCLI:
 
 def main():
     cli = RelyComplyCLI()
-    cli.run_command(sys.argv)
+    cli.run_command(sys.argv[1:])
